ImageViewState class

Inheritance

Constructors

ImageViewState({required double widthNeeded, required double heightNeeded, VoidCallback? onPressed, AssetImage? assetAspectRatio, AssetImage? assetBackground, String? urlAspectRation, String? urlBackground, double? radius_all, double? radius_topLeft, double? radius_topRight, double? radius_bottomLeft, double? radius_bottomRight, Color? colorBackground, EdgeInsets? padding, EdgeInsets? margin, double? opacity, Alignment? gravityLayout_alignment, bool? responsive_auto})

Properties

assetAspectRatio ↔ AssetImage?
getter/setter pair
assetBackground ↔ AssetImage?
getter/setter pair
boarderRadius ↔ BorderRadius
getter/setter pair
colorBackground ↔ Color?
getter/setter pair
context → BuildContext
The location in the tree where this widget builds.
no setterinherited
gravityLayout_alignment ↔ Alignment?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
height ↔ double
getter/setter pair
imageProviderChoosed ↔ ImageProvider<Object>
getter/setter pair
isAssestFound ↔ bool
getter/setter pair
isBothUrlAndAssetFound ↔ bool
getter/setter pair
isModeAspectRatio ↔ bool
getter/setter pair
isModeBackground ↔ bool
getter/setter pair
isModeBoth ↔ bool
getter/setter pair
isUrlFound ↔ bool
getter/setter pair
margin ↔ EdgeInsets?
getter/setter pair
mounted → bool
Whether this State object is currently in a tree.
no setterinherited
onPressed ↔ VoidCallback?
getter/setter pair
opacity ↔ double?
getter/setter pair
padding ↔ EdgeInsets?
getter/setter pair
radius_all ↔ double?
getter/setter pair
radius_bottomLeft ↔ double?
getter/setter pair
radius_bottomRight ↔ double?
getter/setter pair
radius_topLeft ↔ double?
getter/setter pair
radius_topRight ↔ double?
getter/setter pair
responsive_auto ↔ bool?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tag ↔ String
getter/setter pair
urlAspectRation ↔ String?
getter/setter pair
urlBackground ↔ String?
getter/setter pair
widget → ImageView
The current configuration.
no setterinherited
width ↔ double
getter/setter pair

Methods

activate() → void
Called when this object is reinserted into the tree after having been removed via deactivate.
inherited
build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
chooseAssetName() → String
chooseFitBox() → BoxFit
chooseUrl() → String
clickOnThisArea(Widget cont) → Widget
deactivate() → void
Called when this object is removed from the tree.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
didChangeDependencies() → void
Called when a dependency of this State object changes.
inherited
didUpdateWidget(covariant ImageView oldWidget) → void
Called whenever the widget configuration changes.
inherited
dispose() → void
Called when this object is removed from the tree permanently.
inherited
EmptyViewSizeImage() → Widget
getBoxFit_background() → BoxFit
getContent() → Widget
getUrlVailed() → String?
getViewMode_aspectRatio() → Widget
getViewMode_background() → Widget
initIsBoth() → void
initState() → void
Called when this object is inserted into the tree.
inherited
initValues() → void
isVisibleWidget(BuildContext context) → bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reassemble() → void
Called whenever the application is reassembled during debugging, for example during hot reload.
inherited
setImageAspectRationUrl(String updateUrl) → void
setImageBackgroundUrl(String updateUrl) → void
setOpacity(Widget view) → Widget
setState(VoidCallback fn) → void
Notify the framework that the internal state of this object has changed.
inherited
setSurroundWidget(Widget view) → Widget
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringShort() → String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

isValid(String? str) → bool