ScrollSpeed class

how to use "ScrollSpeed" 1- at initState():

@override void initState() { super.initState();

scrollSpeed = ScrollSpeed(context, speed: 4,
    speedForMobileBrowserOnly: false );

}

2- at view : // content SingleChildScrollView( keyboardDismissBehavior: ScrollViewKeyboardDismissBehavior.onDrag, controller: scrollSpeed!.getScrollController(), //here line physics: NeverScrollableScrollPhysics() , child: getColumnTemplate(), // child: getColumnTemplateTestLoop(), ),

Constructors

ScrollSpeed(BuildContext context, {required double speed})

Properties

animateJumpTime ↔ double
getter/setter pair
constantTimeToWaitForTouch → int
final
context ↔ BuildContext
getter/setter pair
counterEvent ↔ int
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
minPixelToTakeAction → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scrollController ↔ ScrollController
getter/setter pair
speed ↔ double
getter/setter pair
tag → String
final
totalOffset_oneWay ↔ double
getter/setter pair
touchEnd ↔ bool
getter/setter pair

Methods

getScrollController() → ScrollController
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
updateTouchContinue(DragUpdateDetails details) → Future

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

historyLog ↔ List<int>
getter/setter pair
totalHistory ↔ double
getter/setter pair