SpinnerView class

Inheritance
Annotations
  • @Deprecated("Use Widget (DropdownFastor.dart) class instead")

Constructors

SpinnerView({required List<Widget> childers, required Widget hintWidget, required double width_frame, required double height_frame, required double iconSize, required SpinnerViewCallBack onSelectPosition, double? radiusButton, Decoration? decorationOutlineDropdown, Widget? iconDropdown, TextStyle? textStyleItemDropdown, Color? colorDropdownMenu, Color? colorDropdownButtonOutline, Color? colorDropdownTextBackground, Color? underlineColor, int? previousPosition, String? errorBackendKeyJson, Map<String, dynamic>? errorBackendJson, TextStyle? errorTextStyle, Decoration? errorOutlineDropdownDropdown, TextDirection? textDirection, @deprecated ValueChanged<SpinnerViewState>? changeState})

Properties

changeState ↔ ValueChanged<SpinnerViewState>?
getter/setter pair
childers ↔ List<Widget>
getter/setter pair
colorDropdownButtonOutline ↔ Color?
getter/setter pair
colorDropdownMenu ↔ Color?
getter/setter pair
colorDropdownTextBackground ↔ Color?
getter/setter pair
decorationOutlineDropdown ↔ Decoration?
getter/setter pair
errorBackendJson ↔ Map<String, dynamic>?
getter/setter pair
errorBackendKeyJson ↔ String?
getter/setter pair
errorMessageBackend ↔ String?
getter/setter pair
errorOutlineDropdownDropdown ↔ Decoration?
getter/setter pair
errorTextStyle ↔ TextStyle?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
height_frame ↔ double
getter/setter pair
hintWidget ↔ Widget
getter/setter pair
iconDropdown ↔ Widget?
getter/setter pair
iconSize ↔ double
getter/setter pair
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onSelectPosition ↔ SpinnerViewCallBack
getter/setter pair
previousPosition ↔ int?
getter/setter pair
radiusButton ↔ double?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
textDirection ↔ TextDirection?
getter/setter pair
textStyleItemDropdown ↔ TextStyle?
getter/setter pair
underlineColor ↔ Color?
getter/setter pair
width_frame ↔ double
getter/setter pair

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → SpinnerViewState
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
fixWidthWithIconSpinner() → void
isHaveError() → bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setDefaultValue() → void
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

key_position_hint → String
final